========
Overview
========

Here, we present a (growing) series of working examples of how to use the cwepr package to perform both, day-to-day routine tasks in a laboratory working with cw-EPR spectroscopy as well as more complex processing and analysis tasks.

For each of the examples, a full recipe is provided ready to be copied and pasted and run on your local computer.

.. note::

    There are plans to provide a series of real example data as well, to make it easy to get first-hand experience with the cwepr package.


Prerequisites
=============

To be able to run the example recipes locally, you need to have a working installation of the cwepr package and its dependencies. Have a look at the :doc:`installation instructions <../installing>` for details.

Furthermore, to be able to run ("cook") the recipes and get ("serve") the results, you need to have access to a command line, as running recipes (still) is command-line based using the command :samp:`serve {recipe.yaml}`.

For some recipes, you will need to have a working LaTeX installation in case you would like to get your reports not only created, but compiled into a well-formatted PDF document as well.

